require 'workarea'
require 'workarea/storefront'
require 'workarea/admin'
require "valken/shipping/engine"

module Valken
  module Shipping

    def self.ups_credentials
      return {} unless Rails.application.secrets.ups_carrier.present?
      Rails.application.secrets.ups_carrier.symbolize_keys
    end

    def self.fedex_credentials
      return {} unless Rails.application.secrets.fedex_carrier.present?
      Rails.application.secrets.fedex_carrier.symbolize_keys
    end

    def self.ups_gateway=(gateway)
      Workarea.config.gateways.ups_carrier = gateway
    end

    def self.fedex_gateway=(gateway)
      Workarea.config.gateways.fedex_carrier = gateway
    end

    def self.auto_initialize_gateway      
      if ups_credentials.present? && !Workarea.config.default_shipping
        if Rails.env.test?
          Workarea.config.gateways.shipping = ActiveShipping::Workarea.new
        else
          Workarea.config.gateways.shipping = ActiveShipping::VALKEN.new ups_credentials
        end
      else
        Workarea.config.gateways.shipping = ActiveShipping::Workarea.new
      end
    end
  end
end